==> vpn-user-portal-3.5.6.tgz: vpn-user-portal/locale/fr-FR.php <==
<?php

declare(strict_types=1);

/*
 * eduVPN - End-user friendly VPN.
 *
 * Copyright: 2014-2023, The Commons Conservancy eduVPN Programme
 * SPDX-License-Identifier: AGPL-3.0+
 */

return [
    //'#Active (Max #Available) Connections' => '',
    '#Connections in 5 minute intervals' => 'Nombre de connexions dans un intervalle de 5 minutes',
    //'#Unique Guest Users' => '',
    '#Unique Users' => 'Nombre d\'utilisateurs uniques',
    '#Unique users and max #connections per day' => 'Nombre d\'utilisateurs et de connexion par jour',
    'ACL Permission List' => 'Liste de autorisations ACL',
    'Account' => 'Compte',
    'Active' => 'Active',
    'Active Configurations' => 'Configurations Actives',
    'Aggregated' => 'Regroupé',
    'All' => 'Tout',
    'An application attempts to establish a VPN connection.' => 'Une application essaie d\'établir une connexion VPN.',
    'An error occurred.' => 'Une erreur est survenue.',
    'Application Usage' => 'Utilisation de l\'application',
    'Approve' => 'Approuver',
    'Approve Application' => 'Approuver l\'application',
    //'Authentication Data' => '',
    'Authorized Applications' => 'Applications autorisées',
    'Authorized On' => 'Autorisé à',
    'Available Profiles' => 'Profils Disponibles',
    'Block LAN' => 'Bloquer LAN',
    'CA' => 'CA',
    'CPU Usage:' => 'Utilisation UCT',
    'Change Password' => 'Modifier le mot de passe',
    'Configurations' => 'Configurations',
    'Confirm' => 'Confirmer',
    'Connected' => 'Connecté',
    'Connections' => 'Connexions',
    'Created On' => 'Créé à',
    'Current Password' => 'Mot de passe actuel',
    'Current Password not correct!' => 'Le mot de passe actuel saisi n\'est pas correct !',
    'Currently there are no clients connected to this profile.' => 'Il n\'y a pour le moment aucun client conncté avec ce profile',
    'DNS Search Domain(s)' => 'Domaine(s) de recherche DNS',
    'DNS Server(s)' => 'Serveurs DNS',
    'Danger Zone' => 'Zône Dangeureuse',
    'Date/Time' => 'Date/Heure',
    'Default Gateway' => 'Passerelle par défaut',
    'Delete' => 'Supprimer',
    'Delete Account' => 'Supprimer le compte',
    'Delete Account Data' => 'Supprimer les données du compte',
    'Disable Account' => 'Désactivé le compte',
    'Disabled' => 'Désactivé',
    'Disconnected' => 'Déconnecté',
    'Distribution of unique users over the VPN applications.' => 'Répartition des utilisateurs uniques sur les applications VPN.',
    'Download' => 'Télécharger',
    'Downloading VPN configurations is not allowed. Please use a VPN application.' => 'Téléchargement des configurations VPN non autorisé. Utilisez s\'il-vous-plait un application VPN',
    'Enable Account' => 'Activer un compte',
    'Error' => 'Erreur',
    'Excluded Route(s)' => 'Routes Exclues',
    'Expires On' => 'Expire le',
    'Export (CSV)' => 'Exporter (CSV)',
    'Find the user identifier that used an IPv4 or IPv6 address at a particular point in time.' => 'Trouver l\'identifiant utilisateur ayant utilisé une adresse IPv4 ou IPv6 à une heure spécifique',
    'Fingerprint' => 'Empreinte',
    'Here you can change the password for your account.' => 'Sur cette page vous pouvez modifier le mot de passe associé à votre compte.',
    'Home' => 'Accueil',
    'Hostname' => 'Nom de l\'hôte',
    'IP Address' => 'Adresse IP',
    'IPs' => 'IP',
    'IPv4 Prefix' => 'Préfixe IPv4',
    'IPv6 Prefix' => 'Préfixe IPv6',
    'Import or copy/paste this configuration to your WireGuard application.' => 'Importer ou faire un copier/coller des cette configuration dans votre application WireGuard.',
    'Info' => 'Informations',
    'Issues' => 'Problèmes',
    'Live' => 'En direct',
    'Log' => 'Journaux',
    //'MTU' => '',
    'Max #Connections' => 'Nombre maximum de Connexions',
    'More' => 'Plus',
    'N/A' => 'N/A',
    'Name' => 'Nom',
    'New Configuration' => 'Nouvelle Configuration',
    'New Password' => 'Nouveau mot de passe',
    'New Password (confirm)' => 'Nouveau mot de passe (confirmer)',
    'New Password and New Password (confirm) MUST match!' => 'Nouveau mot de passe et nouveau mot de passe (confirmer) DOIVENT être identiques !',
    'No Permission(s)' => 'Pas d\'autorisation',
    'No VPN profiles are available for your account.' => 'Aucun profil VPN disponible pour votre compte.',
    'Node URL' => 'URL du noeud',
    'Node(s)' => 'Noeuds',
    'OAuth' => 'OAuth',
    'Obtain a new VPN configuration file for use in your VPN client.' => 'Obtenir un nouveau fichier de configuration VPN pour à utiliser dans votre client VPN.',
    'Offered Ports' => 'Ports offerts',
    'Offline' => 'Hors ligne',
    'Online' => 'En ligne',
    'Only approve this when you are trying to establish a VPN connection with this application!' => 'N\'approuvez ceci que lorsque vous essayez d\'établir une connexion VPN avec cette application',
    'OpenVPN' => 'OpenVPN',
    //'OpenVPN (Prefer TCP)' => '',
    //'OpenVPN (Prefer UDP)' => '',
    'OpenVPN Server Log' => 'Journal du serveur OpenVPN',
    'Password' => 'Mot de passe',
    'Permissions' => 'Autorisations',
    'Please sign in with your username and password.' => 'Veuillez saisir votre identifiant et votre mot de passe.',
    'Port' => 'Port',
    'Ports' => 'Ports',
    'Preferred Protocol' => 'Protocole préféré',
    'Profile' => 'Profil',
    //'Profile ID' => '',
    'Profile Usage' => 'Utilisation du profil',
    'Profile(s)' => 'Profil(s)',
    'Public Key' => 'Clé publique',
    //'Refresh' => '',
    'Results' => 'Résultats',
    'Revoke' => 'Révoquer',
    'Route(s)' => 'Route(s)',
    'Search' => 'Rechercher',
    'Select a profile and choose a name, e.g. "Phone".' => 'Sélectionner un profil et choisir un libellé, par exemple : « Téléphone »',
    'Server' => 'Serveur',
    'Sign In' => 'Se connecter',
    'Sign Out' => 'Déconnexion',
    'Stats' => 'Statistiques',
    'The <em>Date/Time</em> MUST be in UTC.' => 'La <em>date/l\'heure</em> doit être en UTC.',
    'The <em>Date/Time</em> field accepts dates of the format <code>Y-m-d H:i:s</code>, e.g. <code>2019-01-01 08:00:00</code>.' => 'Le champ <em>Date/Heure</em> accepte les dates au format <code>Y-m-d H:i:s</code>, par exemple <code>2019-01-01 08:00:00</code>',
    'The credentials you provided were not correct.' => 'L\'identifiant et/ou le mot de passe que vous avez saisis ne sont pas corrects.',
    'The list of applications you authorized to create a VPN connection.' => 'La liste des applications que vous avez autorisé à créer des connexions VPN.',
    'The maximum number of simultaneously connected VPN clients at a particular moment in time over the last week' => 'Le nombre maximum de clients VPN connectés simultanément à un moment donné dans le courant de la semaine dernière',
    'The most recent VPN connections with this account.' => 'La connexion VPN la plus récente de ce compte.',
    //'The number of currently connected VPN clients, and the maximum possible number of connected VPN clients based on available IP-space for this profile.' => '',
    //'The number of unique guest users connecting to the VPN service in the last week' => '',
    'The number of unique users connecting to the VPN service in the last week' => 'Le nombre d\'utilisateurs uniques connectés simultanément au service VPN dans le courant de la semaine dernière',
    'The table below shows the per profile VPN usage over the last week.' => 'Le tableau ce-dessous montre l\'usage par profil dans le courant de la semaine dernière.',
    'There are no results matching your criteria.' => 'Il n\'y a pas de résultat correspondant à vos critères.',
    'This server uses an external authentication source. Deleting the account data will not prevent the user from authenticating (again)!' => 'Ce serveur utilise une source d\'authentification externe. Effacer les données de ce compte n\'empêchera pas l\'utilisateur de se réauthentifier (à nouveau)!',
    'This user does not have any active configurations.' => 'Cet utilisateur n\'a aucune configuration active.',
    'This user does not have any connections.' => 'Cet utilisateur n\'a aucune connexion.',
    'To prevent malicious applications from secretly establishing a VPN connection on your behalf, you have to explicitly approve this application first.' => 'Pour éviter que des applications établissent secrètement une connexion VPN en votre nom, vous devez d\'abord approuver cette application explicitement.',
    'Use the WireGuard app on your mobile device to scan this QR code.' => 'Utilisez l\'app WireGuard sur votre appareil mobile afin de scanner ce code QR.',
    'User ID' => 'Identifiant utilisateur',
    'Username' => 'Identifiant',
    'Users' => 'Utilisateurs',
    'VPN Portal' => 'Portail VPN',
    'Version' => 'Version',
    'Welcome to this VPN service!' => 'Bienvenue sur ce service VPN !',
    'Why is this necessary?' => 'Pourquoi est-ce nécessaire ?',
    'WireGuard' => 'WireGuard',
    'WireGuard Configuration' => 'Configuration WireGuard',
    'You can download the detailed VPN usage statistics below.' => 'Vous pouvez télécharger les statistiques détaillées sur l\'utilisation du VPN ci-dessous.',
    'You cannot manage your own user account.' => 'Vous ne pouvez pas gérer votre propre compte utilisateur.',
    'You have reached the maximum number of allowed active VPN configurations. Delete some first.' => 'Vous avez atteint le nombre maximal de configurations VPN autorisées. Effacez-en d\'abord.',
    'Your account does not have access to any VPN profile.' => 'Votre compte n\'a accès à aucun profile VPN.',
    'Your new configuration will expire on %expiryDate%. Come back here to obtain a new configuration after expiry!' => 'Votre nouvelle configuration expirera le  %expiryDate%. revenez ici pour obtenir une nouvelle configuration après expiration.',
];

==> vpn-user-portal-3.9.4.tgz: vpn-user-portal/locale/fr-FR.php <==
<?php

declare(strict_types=1);

/*
 * eduVPN - End-user friendly VPN.
 *
 * Copyright: 2014-2023, The Commons Conservancy eduVPN Programme
 * SPDX-License-Identifier: AGPL-3.0+
 */

return [
    '#Active (Max #Available) Connections' => '#de connexions actives (#maximum de connexions possibles)',
    '#Connections in 5 minute intervals' => 'Nombre de connexions dans un intervalle de 5 minutes',
    '#Unique Guest Users' => '#d\'utilisateurs invités uniques',
    '#Unique Users' => 'Nombre d\'utilisateurs uniques',
    '#Unique users and max #connections per day' => 'Nombre d\'utilisateurs et de connexion par jour',
    'ACL Permission List' => 'Liste de autorisations ACL',
    'Account' => 'Compte',
    'Active' => 'Active',
    'Active Configurations' => 'Configurations Actives',
    //'Additional Credential' => '',
    'Aggregated' => 'Regroupé',
    'All' => 'Tout',
    'An application attempts to establish a VPN connection.' => 'Une application essaie d\'établir une connexion VPN.',
    'An error occurred.' => 'Une erreur est survenue.',
    'Application Usage' => 'Utilisation de l\'application',
    'Approve' => 'Approuver',
    'Approve Application' => 'Approuver l\'application',
    'Authentication Data' => 'Données d\'authentification\'',
    'Authorized Applications' => 'Applications autorisées',
    'Authorized On' => 'Autorisé à',
    'Available Profiles' => 'Profils Disponibles',
    'Block LAN' => 'Bloquer LAN',
    'CA' => 'CA',
    'CPU Usage:' => 'Utilisation UCT',
    'Change Password' => 'Modifier le mot de passe',
    'Configurations' => 'Configurations',
    'Confirm' => 'Confirmer',
    'Connected' => 'Connecté',
    'Connections' => 'Connexions',
    'Created On' => 'Créé à',
    'Current Password' => 'Mot de passe actuel',
    'Current Password not correct!' => 'Le mot de passe actuel saisi n\'est pas correct !',
    'Currently there are no clients connected to this profile.' => 'Il n\'y a pour le moment aucun client conncté avec ce profile',
    'DNS Search Domain(s)' => 'Domaine(s) de recherche DNS',
    'DNS Server(s)' => 'Serveurs DNS',
    'Danger Zone' => 'Zône Dangeureuse',
    'Database' => 'Base de données',
    'Date/Time' => 'Date/Heure',
    'Default Gateway' => 'Passerelle par défaut',
    'Delete' => 'Supprimer',
    'Delete Account' => 'Supprimer le compte',
    'Delete Account Data' => 'Supprimer les données du compte',
    'Disable Account' => 'Désactivé le compte',
    'Disabled' => 'Désactivé',
    'Disconnected' => 'Déconnecté',
    'Distribution of unique users over the VPN applications.' => 'Répartition des utilisateurs uniques sur les applications VPN.',
    'Download' => 'Télécharger',
    'Downloading VPN configurations is not allowed. Please use a VPN application.' => 'Téléchargement des configurations VPN non autorisé. Utilisez s\'il-vous-plait un application VPN',
    'Driver' => 'Pilote',
    'Enable Account' => 'Activer un compte',
    'Error' => 'Erreur',
    'Excluded Route(s)' => 'Routes Exclues',
    'Expires On' => 'Expire le',
    'Export (CSV)' => 'Exporter (CSV)',
    //'Extend' => '',
    //'Extend the validity of the configuration until %expiryDate%' => '',
    'Find the user identifier that used an IPv4 or IPv6 address at a particular point in time.' => 'Trouver l\'identifiant utilisateur ayant utilisé une adresse IPv4 ou IPv6 à une heure spécifique',
    'Fingerprint' => 'Empreinte',
    'Here you can change the password for your account.' => 'Sur cette page vous pouvez modifier le mot de passe associé à votre compte.',
    'Home' => 'Accueil',
    'Hostname' => 'Nom de l\'hôte',
    'IP Address' => 'Adresse IP',
    'IPs' => 'IP',
    'IPv4 Prefix' => 'Préfixe IPv4',
    'IPv6 Prefix' => 'Préfixe IPv6',
    'Import or copy/paste this configuration to your WireGuard application.' => 'Importer ou faire un copier/coller des cette configuration dans votre application WireGuard.',
    'Info' => 'Informations',
    'Issues' => 'Problèmes',
    //'Keepalive' => '',
    'Last Used' => 'Dernière utilisation',
    'Live' => 'En direct',
    'Log' => 'Journaux',
    'MTU' => 'MTU',
    //'Maintenance' => '',
    'Max #Connections' => 'Nombre maximum de Connexions',
    'More' => 'Plus',
    'N/A' => 'N/A',
    'Name' => 'Nom',
    'New Configuration' => 'Nouvelle Configuration',
    'New Password' => 'Nouveau mot de passe',
    'New Password (confirm)' => 'Nouveau mot de passe (confirmer)',
    'New Password and New Password (confirm) MUST match!' => 'Nouveau mot de passe et nouveau mot de passe (confirmer) DOIVENT être identiques !',
    'No Permission(s)' => 'Pas d\'autorisation',
    'No VPN profiles are available for your account.' => 'Aucun profil VPN disponible pour votre compte.',
    'Node URL' => 'URL du noeud',
    'Node(s)' => 'Noeuds',
    'OAuth' => 'OAuth',
    'Obtain a new VPN configuration file for use in your VPN client.' => 'Obtenir un nouveau fichier de configuration VPN pour à utiliser dans votre client VPN.',
    'Offered Ports' => 'Ports offerts',
    'Offline' => 'Hors ligne',
    'Online' => 'En ligne',
    'Only approve this when you are trying to establish a VPN connection with this application!' => 'N\'approuvez ceci que lorsque vous essayez d\'établir une connexion VPN avec cette application',
    'OpenVPN' => 'OpenVPN',
    'OpenVPN (Prefer TCP)' => 'OpenVPN (préférer TCP)',
    'OpenVPN (Prefer UDP)' => 'OpenVPN (préférer UDP)',
    'OpenVPN Server Log' => 'Journal du serveur OpenVPN',
    'Password' => 'Mot de passe',
    'Permissions' => 'Autorisations',
    'Please sign in with your username and password.' => 'Veuillez saisir votre identifiant et votre mot de passe.',
    'Port' => 'Port',
    'Ports' => 'Ports',
    'Preferred Protocol' => 'Protocole préféré',
    'Profile' => 'Profil',
    'Profile ID' => 'ID du profil',
    'Profile Usage' => 'Utilisation du profil',
    //'Profile no longer available with your current permissions.' => '',
    'Profile(s)' => 'Profil(s)',
    //'Proxy URL' => '',
    'Public Key' => 'Clé publique',
    'Refresh' => 'Actualise',
    'Results' => 'Résultats',
    'Revoke' => 'Révoquer',
    'Route(s)' => 'Route(s)',
    'Search' => 'Rechercher',
    'Select a profile and choose a name, e.g. "Phone".' => 'Sélectionner un profil et choisir un libellé, par exemple : « Téléphone »',
    'Server' => 'Serveur',
    'Sign In' => 'Se connecter',
    'Sign Out' => 'Déconnexion',
    'Sorted by "Last Used", most recently used first.' => 'Ordonner par "Dernière utilisation", en commençant le dernier profil utilisé',
    'Stats' => 'Statistiques',
    //'TCP' => '',
    'The <em>Date/Time</em> MUST be in UTC.' => 'La <em>date/l\'heure</em> doit être en UTC.',
    'The <em>Date/Time</em> field accepts dates of the format <code>Y-m-d H:i:s</code>, e.g. <code>2019-01-01 08:00:00</code>.' => 'Le champ <em>Date/Heure</em> accepte les dates au format <code>Y-m-d H:i:s</code>, par exemple <code>2019-01-01 08:00:00</code>',
    'The credentials you provided were not correct.' => 'L\'identifiant et/ou le mot de passe que vous avez saisis ne sont pas corrects.',
    'The list of applications you authorized to create a VPN connection.' => 'La liste des applications que vous avez autorisé à créer des connexions VPN.',
    'The maximum number of simultaneously connected VPN clients at a particular moment in time over the last week' => 'Le nombre maximum de clients VPN connectés simultanément à un moment donné dans le courant de la semaine dernière',
    'The most recent VPN connections with this account.' => 'La connexion VPN la plus récente de ce compte.',
    'The number of currently connected VPN clients, and the maximum possible number of connected VPN clients based on available IP-space for this profile.' => 'Nombre de clients VPN actuellement connectés et nombre maximum possible de clients VPN connectés selon l\'espace IP disponible pour ce profil',
    'The number of unique guest users connecting to the VPN service in the last week' => 'Nombre d\'utilisateurs invites uniques connectés au service VPN dans les 7 derniers jours',
    'The number of unique users connecting to the VPN service in the last week' => 'Le nombre d\'utilisateurs uniques connectés simultanément au service VPN dans le courant de la semaine dernière',
    'The table below shows the per profile VPN usage over the last week.' => 'Le tableau ce-dessous montre l\'usage par profil dans le courant de la semaine dernière.',
    'There are no results matching your criteria.' => 'Il n\'y a pas de résultat correspondant à vos critères.',
    'This server uses an external authentication source. Deleting the account data will not prevent the user from authenticating (again)!' => 'Ce serveur utilise une source d\'authentification externe. Effacer les données de ce compte n\'empêchera pas l\'utilisateur de se réauthentifier (à nouveau)!',
    'This user does not have any active configurations.' => 'Cet utilisateur n\'a aucune configuration active.',
    'This user does not have any authorized applications.' => 'Cet utilisateur n\'a pas d\'applications autorisées',
    'This user does not have any connections.' => 'Cet utilisateur n\'a aucune connexion.',
    //'To complete the sign in, you need to provide an additional credential.' => '',
    'To prevent malicious applications from secretly establishing a VPN connection on your behalf, you have to explicitly approve this application first.' => 'Pour éviter que des applications établissent secrètement une connexion VPN en votre nom, vous devez d\'abord approuver cette application explicitement.',
    //'Transport Protocol(s)' => '',
    //'UDP' => '',
    'Use the WireGuard app on your mobile device to scan this QR code.' => 'Utilisez l\'app WireGuard sur votre appareil mobile afin de scanner ce code QR.',
    'User ID' => 'Identifiant utilisateur',
    'Username' => 'Identifiant',
    'Users' => 'Utilisateurs',
    'VPN Portal' => 'Portail VPN',
    'Version' => 'Version',
    'Welcome to this VPN service!' => 'Bienvenue sur ce service VPN !',
    'Why is this necessary?' => 'Pourquoi est-ce nécessaire ?',
    'WireGuard' => 'WireGuard',
    'WireGuard (TCP)' => 'WireGuard (TCP)',
    'WireGuard (UDP)' => 'WireGuard (UDP)',
    'WireGuard Configuration' => 'Configuration WireGuard',
    'You can download the detailed VPN usage statistics below.' => 'Vous pouvez télécharger les statistiques détaillées sur l\'utilisation du VPN ci-dessous.',
    'You cannot manage your own user account.' => 'Vous ne pouvez pas gérer votre propre compte utilisateur.',
    'You have reached the maximum number of allowed active VPN configurations. Delete some first.' => 'Vous avez atteint le nombre maximal de configurations VPN autorisées. Effacez-en d\'abord.',
    'Your account does not have access to any VPN profile.' => 'Votre compte n\'a accès à aucun profile VPN.',
    'Your new configuration will expire on %expiryDate%. Come back here to obtain a new configuration after expiry!' => 'Votre nouvelle configuration expirera le  %expiryDate%. revenez ici pour obtenir une nouvelle configuration après expiration.',
];
